« get me outta code hell

tui-lib - Pure Node.js library for making visual command-line programs (ala vim, ncdu)
about summary refs log tree commit diff
path: root/util/Flushable.js
diff options
context:
space:
mode:
Diffstat (limited to 'util/Flushable.js')
-rw-r--r--util/Flushable.js9
1 files changed, 8 insertions, 1 deletions
diff --git a/util/Flushable.js b/util/Flushable.js
index 6546b7a..318bb52 100644
--- a/util/Flushable.js
+++ b/util/Flushable.js
@@ -16,9 +16,10 @@ module.exports = class Flushable {
     // and ANSI-interpreted compressed size) in the output of flush.
     this.shouldShowCompressionStatistics = false
 
     // Update these if you plan on using the ANSI compressor!
     this.screenLines = 24
     this.screenCols = 80
+    this.lastFrame = undefined
 
     this.ended = false
     this.paused = false
@@ -27,6 +28,12 @@ module.exports = class Flushable {
     this.chunks = []
   }
 
+  resizeScreen({lines, cols}) {
+    this.screenLines = lines
+    this.screenCols = cols
+    this.lastFrame = undefined
+  }
+
   write(what) {
     this.chunks.push(what)
   }
@@ -16,9 +16,10 @@ module.exports = class Flushable {
     this.shouldShowCompressionStatistics = false
 
-    // Update these if you plan on using the ANSI compressor!
+    // Use resizeScreen if you plan on using the ANSI compressor!
     this.screenLines = 24
     this.screenCols = 80